# == Example: ./examples/default-site-init.pp
# 
# Drupal sites are declared as classes that declare an undine::drupal_instance
# resource representing the site's configuration. During installation, Puppet
# will then leverage Drush to download the appropriate version of Drupal core
# and install the site for you.
#
# To use this as the basis for your Drupal site, first locate the "sites"
# directory of your Undine install, then create the subdirectories
# /path/to/undine/sites/undine_default/manifests.
#
# Next, copy this file to ./sites/undine_default/manifests/init.pp.
#
# Finally, add the line "require undine_default" to the file 
# /path/to/undine/manifests/site.pp to tell Undine to configure your site.
#
# The next time you run either "vagrant up" (if you haven't run it yet) or 
# "vagrant provision" (if you have), your changes will be reflected.
#

class undine_default {
  # Require the undine package to ensure dependencies are met.
  require undine

  # Drupal sites are configured by declaring an undine::drupal_instance
  # resource. These parameters will be passed into drush dl and drush si to
  # generate the site in /var/www/default during provisioning. 
  undine::drupal_instance { "default":
    project_name => 'default',
    site_name    => 'Undine Default Site',
    db_name      => 'undine_db',
    db_user      => 'undine',
    db_pass      => 'undine',
    uid1_name    => 'admin',
    uid1_mail    => 'admin@example.com',
    uid1_pass    => 'admin',
    clean_url    => true,
    logoutput    => false,
  }
}
